@@ -1,7 +1,7 @@
 ##Isotope Mixing ,Model with Measurement Error, Source Correlation, Concentration Error and residual error
 ##doesnt estimate third source concentration, inputs mean and variance
 ##outputs C:N ratios
-##Jake Ferguson updated 4/3/2011
+##Jake Ferguson updated 5/1/2011
 ##based on original code from moore and semmens 2009
 
 IsotopeRfull <- "model {
@@ -50,12 +50,28 @@ IsotopeRfull <- "model {
     }
   
     D.tau[1:num.iso,1:num.iso,source] <- D.tau.temp[,,source]
-    mu.conc[1:num.iso,source] ~ dmnorm(dmu.prior.mu[,source], dmu.prior.tau[,])
-      
-    for(count in 1:cd.ss[source]) {
-        cd.array[count,1:num.iso,source] ~ dmnorm(mu.conc[,source], D.tau[,,source])
-    }
+#     mu.conc[1:num.iso,source] ~ dmnorm(dmu.prior.mu[,source], dmu.prior.tau[,])
       
+#     for(count in 1:cd.ss[source]) {
+#         cd.array[count,1:num.iso,source] ~ dmnorm(mu.conc[,source], D.tau[,,source])
+#     }
+
+
+	##draws subsource means and fits to data
+    for(sub in 1:subcd.vec[source]) { 
+		subcd[source, sub, 1:num.iso] ~ dmnorm(dmu.prior.mu[,source], dmu.prior.tau)
+	}
+	
+	for(iso in 1:num.iso) {
+		mu.conc[iso, source] <- mean( subcd[source, 1:subcd.vec[source], iso])
+	}
+		
+	for(sub in 1:subcd.vec[source]) {
+		for(index  in subcd.samples[source,sub,1]:subcd.samples[source,sub,2]) {
+			cd.mat[index, ] ~ dmnorm(subcd[source,sub, ], D.tau[ , ,source]);
+		}  
+     }
+
   }
   
   
@@ -154,10 +170,20 @@ IsotopeRfull <- "model {
     tau.source[1:num.iso,1:num.iso,source] <- inverse((cov.source[,,source]%*%rho.mat[,,source]%*%cov.source[,,source]) +  cov.ME + discrimvar.mat )
  
     ##draws subsource means and fit to data
-      mu.source[source,1:num.iso] ~ dmnorm(mu.prior.mu, mu.prior.cov)
-      for(count in 1:source.ss[source]) {
-        source.array[count,,source] ~ dmnorm(mu.source[source,], tau.source[,,source])
-      }
+    for(sub in 1:subsource.vec[source]) { 
+		subsource[source, sub, 1:num.iso] ~ dmnorm(mu.prior.mu, mu.prior.cov)
+	}
+	
+	for(iso in 1:num.iso) {
+		mu.source[source, iso] <- mean( subsource[source, 1:subsource.vec[source], iso])
+	}
+		
+	for(sub in 1:subsource.vec[source]) {
+		for(index  in subsource.samples[source,sub,1]:subsource.samples[source,sub,2]) {
+			source.mat[index, ] ~ dmnorm(subsource[source,sub, ], tau.source[ , ,source]);
+		}  
+     }
+
   }#end for sources
   
   
@@ -357,11 +383,21 @@ IsotopeRnoconc <- "model {
     tau.source[1:num.iso,1:num.iso,source] <- inverse((cov.source[,,source]%*%rho.mat[,,source]%*%cov.source[,,source]) +  cov.ME + discrimvar.mat )
  
     ##draws subsource means and fit to data
-      mu.source[source,1:num.iso] ~ dmnorm(mu.prior.mu, mu.prior.cov)
-      for(count in 1:source.ss[source]) {
-        source.array[count,,source] ~ dmnorm(mu.source[source,], tau.source[,,source])
-      }
-  }#end for sources
+    for(sub in 1:subsource.vec[source]) { 
+		subsource[source, sub, 1:num.iso] ~ dmnorm(mu.prior.mu, mu.prior.cov)
+	}
+	
+	for(iso in 1:num.iso) {
+		mu.source[source, iso] <- mean( subsource[source, 1:subsource.vec[source], iso])
+	}
+		
+	for(sub in 1:subsource.vec[source]) {
+		for(index  in subsource.samples[source,sub,1]:subsource.samples[source,sub,2]) {
+			source.mat[index, ] ~ dmnorm(subsource[source,sub, ], tau.source[ , ,source]);
+		}  
+     }
+
+	}#end for sources
   
   
   ####################### 
@@ -529,7 +565,7 @@ IsotopeRnoconcnodiscrim <- "model {
   ##estimate sources
   for(source in 1:num.sources) { 
    ##covariance matrix
-    for(sourcex in 2:(num.iso)) {
+   for(sourcex in 2:(num.iso)) {
       for(sourcey in 1:(sourcex-1)) {
     tau.source.temp[sourcex,sourcey,source] <- 0
       }
@@ -562,10 +598,19 @@ IsotopeRnoconcnodiscrim <- "model {
     tau.source[1:num.iso,1:num.iso,source] <- inverse((cov.source[,,source]%*%rho.mat[,,source]%*%cov.source[,,source]) +  cov.ME )
  
     ##draws subsource means and fit to data
-      mu.source[source,1:num.iso] ~ dmnorm(mu.prior.mu, mu.prior.cov)
-      for(count in 1:source.ss[source]) {
-        source.array[count,,source] ~ dmnorm(mu.source[source,], tau.source[,,source])
-      }
+    for(sub in 1:subsource.vec[source]) { 
+		subsource[source, sub, 1:num.iso] ~ dmnorm(mu.prior.mu, mu.prior.cov)
+	}
+	
+	for(iso in 1:num.iso) {
+		mu.source[source, iso] <- mean( subsource[source, 1:subsource.vec[source], iso])
+	}
+		
+	for(sub in 1:subsource.vec[source]) {
+		for(index  in subsource.samples[source,sub,1]:subsource.samples[source,sub,2]) {
+			source.mat[index, ] ~ dmnorm(subsource[source,sub, ], tau.source[ , ,source]);
+		}  
+     }
   }#end for sources
   
   
@@ -767,10 +812,19 @@ IsotopeRnoconc <- "model {
     tau.source[1:num.iso,1:num.iso,source] <- inverse((cov.source[,,source]%*%rho.mat[,,source]%*%cov.source[,,source]) +  cov.ME + discrimvar.mat )
  
     ##draws subsource means and fit to data
-      mu.source[source,1:num.iso] ~ dmnorm(mu.prior.mu, mu.prior.cov)
-      for(count in 1:source.ss[source]) {
-        source.array[count,,source] ~ dmnorm(mu.source[source,], tau.source[,,source])
-      }
+    for(sub in 1:subsource.vec[source]) { 
+		subsource[source, sub, 1:num.iso] ~ dmnorm(mu.prior.mu, mu.prior.cov)
+	}
+	
+	for(iso in 1:num.iso) {
+		mu.source[source, iso] <- mean( subsource[source, 1:subsource.vec[source], iso])
+	}
+		
+	for(sub in 1:subsource.vec[source]) {
+		for(index  in subsource.samples[source,sub,1]:subsource.samples[source,sub,2]) {
+			source.mat[index, ] ~ dmnorm(subsource[source,sub, ], tau.source[ , ,source]);
+		}  
+     }
   }#end for sources
   
   
@@ -972,10 +1026,19 @@ IsotopeRnoconcnodiscrim <- "model {
     tau.source[1:num.iso,1:num.iso,source] <- inverse((cov.source[,,source]%*%rho.mat[,,source]%*%cov.source[,,source]) +  cov.ME )
  
     ##draws subsource means and fit to data
-      mu.source[source,1:num.iso] ~ dmnorm(mu.prior.mu, mu.prior.cov)
-      for(count in 1:source.ss[source]) {
-        source.array[count,,source] ~ dmnorm(mu.source[source,], tau.source[,,source])
-      }
+    for(sub in 1:subsource.vec[source]) { 
+		subsource[source, sub, 1:num.iso] ~ dmnorm(mu.prior.mu, mu.prior.cov)
+	}
+	
+	for(iso in 1:num.iso) {
+		mu.source[source, iso] <- mean( subsource[source, 1:subsource.vec[source], iso])
+	}
+		
+	for(sub in 1:subsource.vec[source]) {
+		for(index  in subsource.samples[source,sub,1]:subsource.samples[source,sub,2]) {
+			source.mat[index, ] ~ dmnorm(subsource[source,sub, ], tau.source[ , ,source]);
+		}  
+     }
   }#end for sources
   
   
@@ -1154,10 +1217,19 @@ IsotopeRnoconcnome <- "model {
     tau.source[1:num.iso,1:num.iso,source] <- inverse((cov.source[,,source]%*%rho.mat[,,source]%*%cov.source[,,source])  + discrimvar.mat )
  
     ##draws subsource means and fit to data
-      mu.source[source,1:num.iso] ~ dmnorm(mu.prior.mu, mu.prior.cov)
-      for(count in 1:source.ss[source]) {
-        source.array[count,,source] ~ dmnorm(mu.source[source,], tau.source[,,source])
-      }
+    for(sub in 1:subsource.vec[source]) { 
+		subsource[source, sub, 1:num.iso] ~ dmnorm(mu.prior.mu, mu.prior.cov)
+	}
+	
+	for(iso in 1:num.iso) {
+		mu.source[source, iso] <- mean( subsource[source, 1:subsource.vec[source], iso])
+	}
+		
+	for(sub in 1:subsource.vec[source]) {
+		for(index  in subsource.samples[source,sub,1]:subsource.samples[source,sub,2]) {
+			source.mat[index, ] ~ dmnorm(subsource[source,sub, ], tau.source[ , ,source]);
+		}  
+     }
   }#end for sources
   
   
@@ -1230,7 +1302,7 @@ IsotopeRnoconcnome <- "model {
 
 IsotopeRnoconcnomenodiscrim <-  "model {
 
-  for(source in 1:num.sources) {
+	for(source in 1:num.sources) {
       for(iso in 1:num.iso) {
         mu.conc[iso,source] <- 1
       }
@@ -1279,7 +1351,7 @@ IsotopeRnoconcnomenodiscrim <-  "model {
   for(i in 1:N) {
     p.tot[i] <- sum(exp.p[i,1:num.sources]);
       for(source in 1:(num.sources-1)) {
-    p[i,source] <- exp.p[i,source]/p.tot[i];
+		p[i,source] <- exp.p[i,source]/p.tot[i];
       }
     p[i,num.sources] <- 1-sum(p[i,1:(num.sources-1)]);
    
@@ -1331,10 +1403,20 @@ IsotopeRnoconcnomenodiscrim <-  "model {
     tau.source[1:num.iso,1:num.iso,source] <- inverse((cov.source[,,source]%*%rho.mat[,,source]%*%cov.source[,,source])  ); #+ discrimvar.mat )
  
     ##draws subsource means and fit to data
-      mu.source[source,1:num.iso] ~ dmnorm(mu.prior.mu, mu.prior.cov);
-      for(count in 1:source.ss[source]) {
-        source.array[count,,source] ~ dmnorm(mu.source[source,], tau.source[,,source]);
-      }
+    for(sub in 1:subsource.vec[source]) { 
+		subsource[source, sub, 1:num.iso] ~ dmnorm(mu.prior.mu, mu.prior.cov)
+	}
+	
+	for(iso in 1:num.iso) {
+		mu.source[source, iso] <- mean( subsource[source, 1:subsource.vec[source], iso])
+	}
+		
+	for(sub in 1:subsource.vec[source]) {
+		for(index  in subsource.samples[source,sub,1]:subsource.samples[source,sub,2]) {
+			source.mat[index, ] ~ dmnorm(subsource[source,sub, ], tau.source[ , ,source]);
+		}  
+     }
+      
   }#end for sources
   
   
@@ -1449,12 +1531,27 @@ IsotopeRnodiscrim   <- "model {
     }
   
     D.tau[1:num.iso,1:num.iso,source] <- D.tau.temp[,,source]
-    mu.conc[1:num.iso,source] ~ dmnorm(dmu.prior.mu[,source], dmu.prior.tau[,])
+#     mu.conc[1:num.iso,source] ~ dmnorm(dmu.prior.mu[,source], dmu.prior.tau[,])
       
-    for(count in 1:cd.ss[source]) {
-        cd.array[count,1:num.iso,source] ~ dmnorm(mu.conc[,source], D.tau[,,source])
-    }
+#     for(count in 1:cd.ss[source]) {
+#         cd.array[count,1:num.iso,source] ~ dmnorm(mu.conc[,source], D.tau[,,source])
+#     }
       
+	##draws subsource means and fits to data
+    for(sub in 1:subcd.vec[source]) { 
+		subcd[source, sub, 1:num.iso] ~ dmnorm(dmu.prior.mu[,source], dmu.prior.tau)
+	}
+	
+	for(iso in 1:num.iso) {
+		mu.conc[iso, source] <- mean( subcd[source, 1:subcd.vec[source], iso])
+	}
+		
+	for(sub in 1:subcd.vec[source]) {
+		for(index  in subcd.samples[source,sub,1]:subcd.samples[source,sub,2]) {
+			cd.mat[index, ] ~ dmnorm(subcd[source,sub, ], D.tau[ , ,source]);
+		}  
+     }
+
   }
   
   
@@ -1553,10 +1650,19 @@ IsotopeRnodiscrim   <- "model {
     tau.source[1:num.iso,1:num.iso,source] <- inverse((cov.source[,,source]%*%rho.mat[,,source]%*%cov.source[,,source]) +  cov.ME )#+ discrimvar.mat )
  
     ##draws subsource means and fit to data
-      mu.source[source,1:num.iso] ~ dmnorm(mu.prior.mu, mu.prior.cov)
-      for(count in 1:source.ss[source]) {
-        source.array[count,,source] ~ dmnorm(mu.source[source,], tau.source[,,source])
-      }
+    for(sub in 1:subsource.vec[source]) { 
+		subsource[source, sub, 1:num.iso] ~ dmnorm(mu.prior.mu, mu.prior.cov)
+	}
+	
+	for(iso in 1:num.iso) {
+		mu.source[source, iso] <- mean( subsource[source, 1:subsource.vec[source], iso])
+	}
+		
+	for(sub in 1:subsource.vec[source]) {
+		for(index  in subsource.samples[source,sub,1]:subsource.samples[source,sub,2]) {
+			source.mat[index, ] ~ dmnorm(subsource[source,sub, ], tau.source[ , ,source]);
+		}  
+     }
   }#end for sources
   
   
@@ -1662,12 +1768,27 @@ IsotopeRnome <- "model {
     }
   
     D.tau[1:num.iso,1:num.iso,source] <- D.tau.temp[,,source]
-    mu.conc[1:num.iso,source] ~ dmnorm(dmu.prior.mu[,source], dmu.prior.tau[,])
+#     mu.conc[1:num.iso,source] ~ dmnorm(dmu.prior.mu[,source], dmu.prior.tau[,])
       
-    for(count in 1:cd.ss[source]) {
-        cd.array[count,1:num.iso,source] ~ dmnorm(mu.conc[,source], D.tau[,,source])
-    }
+#     for(count in 1:cd.ss[source]) {
+#         cd.array[count,1:num.iso,source] ~ dmnorm(mu.conc[,source], D.tau[,,source])
+#     }
       
+	##draws subsource means and fits to data
+    for(sub in 1:subcd.vec[source]) { 
+		subcd[source, sub, 1:num.iso] ~ dmnorm(dmu.prior.mu[,source], dmu.prior.tau)
+	}
+	
+	for(iso in 1:num.iso) {
+		mu.conc[iso, source] <- mean( subcd[source, 1:subcd.vec[source], iso])
+	}
+		
+	for(sub in 1:subcd.vec[source]) {
+		for(index  in subcd.samples[source,sub,1]:subcd.samples[source,sub,2]) {
+			cd.mat[index, ] ~ dmnorm(subcd[source,sub, ], D.tau[ , ,source]);
+		}  
+     }
+
   }
   
   
@@ -1766,10 +1887,19 @@ IsotopeRnome <- "model {
     tau.source[1:num.iso,1:num.iso,source] <- inverse((cov.source[,,source]%*%rho.mat[,,source]%*%cov.source[,,source]) +  discrimvar.mat )
  
     ##draws subsource means and fit to data
-      mu.source[source,1:num.iso] ~ dmnorm(mu.prior.mu, mu.prior.cov)
-      for(count in 1:source.ss[source]) {
-        source.array[count,,source] ~ dmnorm(mu.source[source,], tau.source[,,source])
-      }
+    for(sub in 1:subsource.vec[source]) { 
+		subsource[source, sub, 1:num.iso] ~ dmnorm(mu.prior.mu, mu.prior.cov)
+	}
+	
+	for(iso in 1:num.iso) {
+		mu.source[source, iso] <- mean( subsource[source, 1:subsource.vec[source], iso])
+	}
+		
+	for(sub in 1:subsource.vec[source]) {
+		for(index  in subsource.samples[source,sub,1]:subsource.samples[source,sub,2]) {
+			source.mat[index, ] ~ dmnorm(subsource[source,sub, ], tau.source[ , ,source]);
+		}  
+     }
   }#end for sources
   
   
@@ -1857,18 +1987,34 @@ IsotopeRnomenodiscrim <- "model {
       for(sourcex in 1:(sourcey-1)) {
         D.tau.temp[sourcex,sourcey,source] <- 0
       }
-    }
-    
+    }    
     for(source2 in 1:num.iso) {
       D.tau.temp[source2,source2,source] ~ dgamma(.001,.001)
     }
   
     D.tau[1:num.iso,1:num.iso,source] <- D.tau.temp[,,source]
-    mu.conc[1:num.iso,source] ~ dmnorm(dmu.prior.mu[,source], dmu.prior.tau[,])
+#     mu.conc[1:num.iso,source] ~ dmnorm(dmu.prior.mu[,source], dmu.prior.tau[,])
       
-    for(count in 1:cd.ss[source]) {
-        cd.array[count,1:num.iso,source] ~ dmnorm(mu.conc[,source], D.tau[,,source])
-    }      
+#     for(count in 1:cd.ss[source]) {
+#         cd.array[count,1:num.iso,source] ~ dmnorm(mu.conc[,source], D.tau[,,source])
+#     }      
+
+
+	##draws subsource means and fits to data
+    for(sub in 1:subcd.vec[source]) { 
+		subcd[source, sub, 1:num.iso] ~ dmnorm(dmu.prior.mu[,source], dmu.prior.tau)
+	}
+	
+	for(iso in 1:num.iso) {
+		mu.conc[iso, source] <- mean( subcd[source, 1:subcd.vec[source], iso])
+	}
+		
+	for(sub in 1:subcd.vec[source]) {
+		for(index  in subcd.samples[source,sub,1]:subcd.samples[source,sub,2]) {
+			cd.mat[index, ] ~ dmnorm(subcd[source,sub, ], D.tau[ , ,source]);
+		}  
+     }
+
   }
   
   
@@ -1936,23 +2082,23 @@ IsotopeRnomenodiscrim <- "model {
    ##covariance matrix
     for(sourcex in 2:(num.iso)) {
       for(sourcey in 1:(sourcex-1)) {
-    tau.source.temp[sourcex,sourcey,source] <- 0
+			tau.source.temp[sourcex,sourcey,source] <- 0
       }
     }
     for(sourcey in 2:(num.iso)) {
       for(sourcex in 1:(sourcey-1)) {
-    tau.source.temp[sourcex,sourcey,source] <- 0
+		tau.source.temp[sourcex,sourcey,source] <- 0
       }
     }
     for(source2 in 1:num.iso) {
-      tau.source.temp[source2,source2,source] ~ dgamma(.0010,.0010)
+		tau.source.temp[source2,source2,source] ~ dgamma(.0010,.0010)
     }
        
     ##build source correlation matrix
     rho.source[source] ~ dunif(-1,1)
     for(sourcex in 2:(num.iso)) {
       for(sourcey in 1:(sourcex-1)) {
-        rho.mat[sourcex,sourcey,source] <- rho.source[source]
+		rho.mat[sourcex,sourcey,source] <- rho.source[source]
       }
     }
     for(sourcey in 2:(num.iso)) {
@@ -1967,10 +2113,19 @@ IsotopeRnomenodiscrim <- "model {
     tau.source[1:num.iso,1:num.iso,source] <- inverse((cov.source[,,source]%*%rho.mat[,,source]%*%cov.source[,,source]))
  
     ##draws subsource means and fit to data
-      mu.source[source,1:num.iso] ~ dmnorm(mu.prior.mu, mu.prior.cov)
-      for(count in 1:source.ss[source]) {
-        source.array[count,,source] ~ dmnorm(mu.source[source,], tau.source[,,source])
-      }
+    for(sub in 1:subsource.vec[source]) { 
+		subsource[source, sub, 1:num.iso] ~ dmnorm(mu.prior.mu, mu.prior.cov)
+	}
+	
+	for(iso in 1:num.iso) {
+		mu.source[source, iso] <- mean( subsource[source, 1:subsource.vec[source], iso])
+	}
+		
+	for(sub in 1:subsource.vec[source]) {
+		for(index  in subsource.samples[source,sub,1]:subsource.samples[source,sub,2]) {
+			source.mat[index, ] ~ dmnorm(subsource[source,sub, ], tau.source[ , ,source]);
+		}  
+     }
   }#end for sources
   
   
