@@ -45,7 +45,6 @@ Tri.plots <- function(jags.1,X,plot.mix=FALSE,plot.ind.flag=FALSE, me.flag=FALSE
   
   cov.conc.index <- grep("sd.conc", jags.names[[1]])
   cov.conc <- jags.table[cov.conc.index, med]
-  
   x.points <- mu.source[1:(length(mu.source)/2)]
   if(me.flag) { x.sd     <- cov.source[1:3] + sigmaz.med[1] } else { 
     x.sd		<- cov.source[1:3] #+ sigmaz.med[1]^2)
@@ -72,22 +71,28 @@ Tri.plots <- function(jags.1,X,plot.mix=FALSE,plot.ind.flag=FALSE, me.flag=FALSE
 
   D.lowCI <- jags.table[D.source.index,low.ci]
   D.hiCI <- jags.table[D.source.index,hi.ci]
-  
-  x.coord <- seq(1,length(D.source),by=2)
-  x.conc <- D.source[x.coord]
-  x.conc.sd <- cov.source[1:3] #sqrt(cov.source[seq(1,12,by=4)])
- 
-  x.conc.lowCI <- x.conc-2*x.conc.sd
-  x.conc.hiCI <- x.conc-2*x.conc.sd
+	if(length(D.source)==0) {
+		x.conc  <- rep(1,3)
+		x.conc.sd <- rep(0,3) 
+		y.conc <- rep(1,3)
+		y.conc.sd <- rep(0,3)
+	} else {
+		x.coord <- seq(1,length(D.source),by=2)
+		x.conc <- D.source[x.coord]
+		x.conc.sd <- cov.source[1:3] 
 
-  y.coord <- seq(2,length(D.source),by=2)
-  y.conc <- D.source[y.coord]
-  y.conc.sd <- cov.source[4:6]
+		y.coord <- seq(2,length(D.source),by=2)
+		y.conc <- D.source[y.coord]
+		y.conc.sd <- cov.source[4:6]
+	}
+	
+		x.conc.lowCI <- x.conc-2*x.conc.sd
+		x.conc.hiCI <- x.conc-2*x.conc.sd
 
-  y.conc.lowCI <- y.conc - 2*y.conc.sd
-  y.conc.hiCI <- y.conc - 2*y.conc.sd
-  
-  axis.raw <- seq(0,1,by=0.2)
+		y.conc.lowCI <- y.conc - 2*y.conc.sd
+		y.conc.hiCI <- y.conc - 2*y.conc.sd
+
+	axis.raw <- seq(0,1,by=0.2)
   base.matrix <- array(NA,c(length(axis.raw),length(axis.raw),3))
   x.matrix <- base.matrix
   xedge.matrix <- base.matrix
@@ -164,11 +169,10 @@ Tri.plots <- function(jags.1,X,plot.mix=FALSE,plot.ind.flag=FALSE, me.flag=FALSE
 
   y.outer.loCI <- apply(y.matrix, c(1,2), '%*%', y.lowCI)
   y.outer.hiCI <- apply(y.matrix, c(1,2), '%*%', y.hiCI)
-
   plotCI(x=x.points, y=y.points, liw=(x.sd), uiw=(x.sd), xlim=(range(x.points) + c(-1,1)*2*max(x.sd)), ylim=(range(y.points) + c(-1,1)*2*max(y.sd)), err="x",pch=19, xlab=expression(paste(delta^13,C)) , ylab=expression(paste(delta^15,N)),col="white")
   plotCI(x=x.points, y=y.points, liw=(y.sd), uiw=(y.sd) ,err="y",add=TRUE,pch=19,col="white")
   box(lwd=2)
-    
+
   base.matrix <- round(base.matrix,1)
   ##draws the grey triangles
   for(x1 in 1:(length(axis.raw))) {
@@ -259,13 +263,15 @@ Bi.plots <- function(jags.1,X,plot.mix=FALSE,plot.ind.flag=FALSE, me.flag=FALSE)
   require(plotrix)
   
   N <- dim(X)[1]
-  
-  jags.names <- dimnames(jags.1$BUGSoutput$summary)
-  jags.table <- jags.1$BUGSoutput$summary
+#   jags.names <- dimnames(jags.1$BUGSoutput$summary)
+#   jags.table <- jags.1$BUGSoutput$summary
+  jags.names <- dimnames(jags.1$summary$quantiles)
+  jags.table <- jags.1$summary$quantiles
+
   med <- which(jags.names[[2]] == '50%')
   low.ci <- which(jags.names[[2]] == '2.5%')
   hi.ci <- which(jags.names[[2]] == '97.5%')
-  
+
   mu.source.index <- grep("mu.source", jags.names[[1]])
   mu.source <- jags.table[mu.source.index,med]
   mu.lowCI <- jags.table[mu.source.index,low.ci]
@@ -273,8 +279,8 @@ Bi.plots <- function(jags.1,X,plot.mix=FALSE,plot.ind.flag=FALSE, me.flag=FALSE)
  
   cov.source.index <- grep("sd.source", jags.names[[1]])
   cov.source <- jags.table[cov.source.index, med]
-
-    if(me.flag) {
+  
+  if(me.flag) {
         sigmaz.index <- grep("sd.me", jags.names[[1]])
         sigmaz.temp <- jags.table[sigmaz.index, med]
         sigmaz.med  <- sigmaz.temp#[c(1,4)]
@@ -313,27 +319,35 @@ Bi.plots <- function(jags.1,X,plot.mix=FALSE,plot.ind.flag=FALSE, me.flag=FALSE)
   y.hiCI <- y.points + 2*y.sd
   
   data.cols="black"
-  
   D.source.index <- grep("mu.conc", jags.names[[1]])
   D.source <- jags.table[D.source.index,med]
 
   D.lowCI <- jags.table[D.source.index,low.ci]
   D.hiCI <- jags.table[D.source.index,hi.ci]
   
-  x.coord <- seq(1,length(D.source),by=2)
-  x.conc <- D.source[x.coord]
-	x.conc.sd <- cov.source[1:2]#sqrt(cov.source[seq(1,8,by=4)])
+  print(cov.source)
+  	if(length(D.source)==0) {
+		x.conc  <- rep(1,2)
+		x.conc.sd <- rep(0,2) 
+		y.conc <- rep(1,2)
+		y.conc.sd <- rep(0,2)
+	} else {
+		x.coord <- seq(1,length(D.source),by=2)
+		x.conc <- D.source[x.coord]
+		x.conc.sd <- cov.source[1:2] 
+
+		y.coord <- seq(2,length(D.source),by=2)
+		y.conc <- D.source[y.coord]
+		y.conc.sd <- cov.source[3:4]
+	}
+
 
   x.conc.lowCI <- x.conc-2*x.conc.sd
   x.conc.hiCI <- x.conc+2*x.conc.sd
-  
-  y.coord <- seq(2,length(D.source),by=2)
-  y.conc <- D.source[y.coord]
-  y.conc.sd <- cov.source[3:4]#sqrt(cov.source[seq(4,8,by=4)])
-  
+
   y.conc.lowCI <- y.conc-2*y.conc.sd
   y.conc.hiCI <- y.conc+2*y.conc.sd
-  
+
   axis.raw <- seq(0,1,by=0.2)
   base.matrix <- array(NA,c(length(axis.raw),2))
   x.matrix <- base.matrix
@@ -346,13 +360,11 @@ Bi.plots <- function(jags.1,X,plot.mix=FALSE,plot.ind.flag=FALSE, me.flag=FALSE)
   y.hiCI.matrix <- base.matrix
   x.outer.matrix <- base.matrix
   y.outer.matrix <- base.matrix
-  
   for(r1 in 1:length(axis.raw)) {
       temp <- 1- axis.raw[r1] #- axis.raw[r2] 
       if(temp >= (0.00-1e-3) & temp <=1.001) {
 	base.matrix[r1,1] <- axis.raw[r1]
 	base.matrix[r1,2] <- 1-axis.raw[r1]#axis.raw[r2]
-	
 	x.matrix[r1,1] <- base.matrix[r1,1]*x.conc[1]/base.matrix[r1,]%*%x.conc
 	x.matrix[r1,2] <- base.matrix[r1,2]*x.conc[2]/base.matrix[r1,]%*%x.conc
 
@@ -382,10 +394,11 @@ Bi.plots <- function(jags.1,X,plot.mix=FALSE,plot.ind.flag=FALSE, me.flag=FALSE)
 	}
     }
   }#end r loop
-
+print('here')
   x.basic <- x.matrix%*%x.points
   y.basic <- y.matrix%*%y.points
-  
+ print(x.points)
+ print(x.matrix)
   x.edge <- xedge.matrix%*%x.points
   y.edge <- yedge.matrix%*%y.points
 
@@ -401,8 +414,7 @@ Bi.plots <- function(jags.1,X,plot.mix=FALSE,plot.ind.flag=FALSE, me.flag=FALSE)
   y.outer.loCI <- y.matrix%*%y.lowCI
   y.outer.hiCI <- y.matrix%*%y.hiCI
   
-    plot(x=x.points, y=y.points, xlim=(range(x.points)+ c(-1,1)*2*x.sd), ylim=range(y.points)+  c(-1,1)*2*y.sd,xlab=expression(paste(delta,C[13])), ylab=expression(paste(delta,N[15])),pch=c(19,19),col=c("grey","grey"))
-
+    plot(x=x.points, y=y.points, xlim=(range(x.points)+ c(-1,1)*2.2*x.sd), ylim=range(y.points)+  c(-1,1)*2.2*y.sd,xlab=expression(paste(delta,C[13])), ylab=expression(paste(delta,N[15])),pch=c(19,19),col=c("grey","grey"))
     points(x.basic,y.basic,type='l',lwd=2,col="grey")  
     
   box(lwd=2)
@@ -413,7 +425,10 @@ Bi.plots <- function(jags.1,X,plot.mix=FALSE,plot.ind.flag=FALSE, me.flag=FALSE)
     title('Estimates')
   }
   
-	rho.vec <- jags.1$BUGSoutput$mean$rho.source
+# 	rho.vec <- jags.1$BUGSoutput$mean$rho.source
+  rho.index <- grep("rho.source", jags.names[[1]])
+  rho.vec <-jags.1$summary$statistics[rho.index,1]
+
 # 	theta <- seq(0, 2 * pi, length=100)
 	for(i in 1:2) {
 		
@@ -452,7 +467,7 @@ Bi.plots <- function(jags.1,X,plot.mix=FALSE,plot.ind.flag=FALSE, me.flag=FALSE)
 #######################################################
 ##plots smoothed histograms of individual distributions
 #######################################################
-curves.plot <- function(jags.1, num.sources, num.chains, color=FALSE,individuals, xlab.vec) {
+curves.plot <- function(jags.1, num.sources, num.chains, color=FALSE,individuals, xlab.vec, num.groups=1) {
 
   output <- jags.1$summary$quantiles
   out.mcmc <- jags.1$mcmc
@@ -476,7 +491,10 @@ curves.plot <- function(jags.1, num.sources, num.chains, color=FALSE,individuals
 
     p.ind <- which(out.names== paste("p[",1,',',j,']',sep='') )
     p.pop <- which(out.names== paste("p.pop[",j,']',sep='') )
-
+	if(num.groups > 1) {
+		p.group <- which(out.names== paste("p.group[",j,']',sep='') )
+	}
+	
     p1.popmed[j] <- output[p.pop, out.perc]
 
     temp.pop <- hist(mcmc.rbind[,p.pop],plot=FALSE, breaks=seq(0,1,length.out=100))
@@ -493,10 +511,27 @@ curves.plot <- function(jags.1, num.sources, num.chains, color=FALSE,individuals
      temp.smooth$y <- temp.smooth$y[-c(1,length(temp.smooth$y))]
      
      
-     if(color) { lines(temp.smooth, type='l', lwd=2, col=rgb(0,0,128,alpha=100,maxColorValue=255)) } else {
-     lines(temp.smooth, type='l', lwd=1, col="white")}    
+     if(color) { lines(temp.smooth, type='l', lwd=2, col='cornflowerblue') } else {
+     lines(temp.smooth, type='l', lwd=1, col="grey")}    
   }
   
+	if(num.groups > 1) {
+  
+		for(i in 1:num.groups) {
+        
+			p.group <- which(out.names== paste("p.group[",i,',',j,']',sep='') )
+			temp <- hist(mcmc.rbind[,p.group],plot=FALSE, breaks=seq(0,1,length.out=100))
+			temp.smooth <- lowess(c(0,temp$mids,1), y= c(0,temp$density,0), f=.1)
+			temp.smooth$x <- temp.smooth$x[-c(1,length(temp.smooth$x))]
+			temp.smooth$y <- temp.smooth$y[-c(1,length(temp.smooth$y))]
+			
+			
+			if(color) { lines(temp.smooth, type='l', lwd=2, col='firebrick2') } else {
+			lines(temp.smooth, type='l', lwd=2, col="black")}    
+		}
+	
+	}
+  
   if(min(pop.smooth$x) > 0.025) {pop.smooth$x <- c(0.025,pop.smooth$x); pop.smooth$y <- c(0,pop.smooth$y)}
   if(max(pop.smooth$x) < 0.975) {pop.smooth$x <- c(pop.smooth$x,0.975); pop.smooth$y <- c(pop.smooth$y,0)}
   lines(pop.smooth, type='l', lwd=2, col="black")
